Name:		Vuurmuur
Version:	0.7
Release:	12%{?dist}
Summary:	Firewall manager built on top of iptables
Group:		System Environment/Libraries
License:	GPLv2+
URL:		http://www.vuurmuur.org/
Source0:	ftp://ftp.vuurmuur.org/releases/%{version}/%{name}-%{version}.tar.gz
Source1:	vuurmuur-initd.sh
# Patch sent to upstream and commited into SVN
Patch0:		libvuurmuur-plugin.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	gettext
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	ncurses-devel

%description
Vuurmuur is a powerful middle-end/front-end for netfilter/iptables aimed
at system-administrators who need a decent firewall, but don't have netfilter
specific knowledge.

The program is basicly split into three pieces. One piece (the middle-end)
converts humanly-readable rules, hosts, groups, networks, zones, interfaces
and services into a iptables ruleset (or optional into a bash-script). The
second part is a little daemon that converts the netfiler logs to easy
readable logs, that reflect all the predefined objects described above. The
third part is a Ncurses-based Gui (the front-end) in which one can manage
the firewall. Most important here is the real-time feedback. Logs can be
viewed in real-time, using colours for easy interpretation. Also, the current
connections can be viewed in real-time. Filtering possibilities make it easy
to monitor specific hosts or services.

%package tui
Summary:	Ncurses based interface for modifying Vuurmuur configuration
Requires:	%{name} = %{version}-%{release}

%description tui
Ncurses based interface for modifying Vuurmuur configuration.

%package daemon
Summary:	Vuurmuur daemon
Requires:	%{name} = %{version}-%{release}
Requires(post):	chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts

%description daemon
Vuurmuur daemon.

%package devel
Summary:	Development files for firewall manager built on top of iptables
Requires:	%{name} = %{version}-%{release} 

%description devel
Development files for firewall manager built on top of iptables

%prep
%setup -q
tar xzf libvuurmuur-%{version}.tar.gz
tar xzf vuurmuur-%{version}.tar.gz
tar xzf vuurmuur_conf-%{version}.tar.gz

cd libvuurmuur-%{version}
# Vuurmuur doesn't obey configure argument for plugin placement. This patch fixes it.
%patch0 -p1
aclocal
libtoolize
autoconf
automake

%build
cd libvuurmuur-%{version}
LIBVUDIR=$(pwd)
%configure \
	--with-plugindir=%{_libdir}/vuurmuur/plugins

# Configure ignores --disable-rpath so we have to solve it this way
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

cd ../vuurmuur-%{version}
%configure \
	--with-libvuurmuur-includes=${LIBVUDIR}/src/ \
	--with-libvuurmuur-libraries=${LIBVUDIR}/src/.libs/

# Configure ignores --disable-rpath so we have to solve it this way
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags}

# Convert MAN pages to UTF-8
pushd man/en
for i in vuurmuur_script.8 vuurmuur_log.8 vuurmuur.8; do
	iconv --from=ISO-8859-1 --to=UTF-8 $i > new
	mv new $i
done
popd

# Convert MAN pages to UTF-8
pushd man/ru
for i in vuurmuur_script.8 vuurmuur_log.8 vuurmuur.8; do
	iconv --from=KOI-8 --to=UTF-8 $i > new
	mv new $i
done
popd

cd ../vuurmuur_conf-%{version}
%configure \
	--with-libvuurmuur-includes=${LIBVUDIR}/src/ \
	--with-libvuurmuur-libraries=${LIBVUDIR}/src/.libs/

# Configure ignores --disable-rpath so we have to solve it this way
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# Parallel build is not supported for this component so it's disabled
make

# Convert MAN pages to UTF-8
pushd man/ru
iconv --from=KOI-8 --to=UTF-8 vuurmuur_conf.8 > new
mv new vuurmuur_conf.8
popd

# Convert HLP pages to UTF-8
pushd help
for i in vuurmuur-fr.hlp vuurmuur-ru.hlp; do
	iconv --from=ISO-8859-1 --to=UTF-8 $i > new
	mv new $i
done
popd

%install
VUDIR=$(pwd)
# Install libraries
rm -rf $RPM_BUILD_ROOT
cd libvuurmuur-%{version}

make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

# Create main configuration directory
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur

# create initial configuration to be able to start Vuurmuur
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/plugins/
install -m 600 -p plugins/textdir/textdir.conf.debian \
	$RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/plugins/textdir.conf

# Install daemon
cd ../vuurmuur-%{version}
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

for i in `find $VUDIR -name .keep`
do
	rm -rf $i
done

# install SYSV init stuff
mkdir -p $RPM_BUILD_ROOT/%{_initddir}
install -m755 %{SOURCE1} \
	$RPM_BUILD_ROOT/%{_initddir}/vuurmuur

# install log rotation stuff
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d
install -m 644 -p scripts/vuurmuur-logrotate \
	$RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/vuurmuur

# create log directory
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/log/vuurmuur

# create initial configuration to be able to start Vuurmuur
install -m 600 -p skel/etc/vuurmuur/config.conf.sample \
	$RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/config.conf
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/
cp -a services $RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/
rm -f $RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/services/Makefile*

# Remove files that should be not packaged
rm -rf $RPM_BUILD_ROOT%{_datadir}/vuurmuur/scripts
rm -rf $RPM_BUILD_ROOT%{_datadir}/vuurmuur/services

# Install ncurses configuration tool
cd ../vuurmuur_conf-%{version}
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

# Install default configuration
#install -m 600 -p config/vuurmuur_conf.conf.sample \
#	$RPM_BUILD_ROOT/%{_sysconfdir}/vuurmuur/vuurmuur_conf.conf

# Remove unpackaged files
rm -rf $RPM_BUILD_ROOT%{_docdir}/vuurmuur
rm -f $RPM_BUILD_ROOT%{_libdir}/libvuurmuur.la
rm -f $RPM_BUILD_ROOT%{_libdir}/vuurmuur/plugins/libtextdir.la
rm -rf $RPM_BUILD_ROOT%{_datadir}/vuurmuur/conf

# Remove static libraries
rm -f $RPM_BUILD_ROOT%{_libdir}/libvuurmuur.a
rm -f $RPM_BUILD_ROOT%{_libdir}/vuurmuur/plugins/libtextdir.a

%find_lang vuurmuur_conf

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post daemon

# Register the vuurmuur service
/sbin/chkconfig --add vuurmuur

%preun daemon
if [ $1 = 0 ]; then
	/sbin/service vuurmuur stop > /dev/null 2>&1
	/sbin/chkconfig --del vuurmuur
fi

%postun daemon
if [ "$1" -ge "1" ] ; then
    /sbin/service vuurmuur condrestart >/dev/null 2>&1 || :
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc libvuurmuur-%{version}/doc/README libvuurmuur-%{version}/AUTHORS libvuurmuur-%{version}/COPYING
%{_libdir}/libvuurmuur.so.0
%{_libdir}/libvuurmuur.so.0.6.0
%dir %{_libdir}/vuurmuur
%dir %{_libdir}/vuurmuur/plugins
%{_libdir}/vuurmuur/plugins/libtextdir.so
%{_libdir}/vuurmuur/plugins/libtextdir.so.0
%{_libdir}/vuurmuur/plugins/libtextdir.so.0.0.0

%files daemon
%defattr(-,root,root,-)
%doc vuurmuur-%{version}/AUTHORS vuurmuur-%{version}/skel vuurmuur-%{version}/zones
%{_bindir}/vuurmuur
%{_bindir}/vuurmuur_log
%{_bindir}/vuurmuur_script
%{_mandir}/man8/vuurmuur.8.gz
%{_mandir}/man8/vuurmuur_log.8.gz
%{_mandir}/man8/vuurmuur_script.8.gz
%lang(ru) %{_mandir}/ru/man8/vuurmuur.8.gz
%lang(ru) %{_mandir}/ru/man8/vuurmuur_log.8.gz
%lang(ru) %{_mandir}/ru/man8/vuurmuur_script.8.gz
%config(noreplace) %{_sysconfdir}/vuurmuur
%config(noreplace) %{_sysconfdir}/logrotate.d/vuurmuur
%{_initddir}/vuurmuur
%dir %{_localstatedir}/log/vuurmuur

%files devel
%defattr(-,root,root,-)
%{_includedir}/vuurmuur.h
%{_libdir}/libvuurmuur.so

%files tui -f vuurmuur_conf-%{version}/vuurmuur_conf.lang
%defattr(-,root,root,-)
%doc vuurmuur_conf-%{version}/AUTHORS vuurmuur_conf-%{version}/ChangeLog vuurmuur_conf-%{version}/COPYING
%{_bindir}/vuurmuur_conf
%{_mandir}/man8/vuurmuur_conf.8.gz
%lang(ru) %{_mandir}/ru/man8/vuurmuur_conf.8.gz
%doc %{_datadir}/vuurmuur

%changelog
* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Nov 23 2009 Stjepan Gros <stjepan.gros@gmail.com> - 0.7-7
- Parallel make enabled for libvuurmuur and disabled for vuurmuur_conf

* Thu Nov 19 2009 Stjepan Gros <stjepan.gros@gmail.com> - 0.7-6
- Fixed macros in changelog

* Wed Nov 18 2009 Stjepan Gros <stjepan.gros@gmail.com> - 0.7-5
- Disabled parallel make
- Fixed ownership of the directory %%{_libdir}/vuurmuur/plugins
- Fix error in startup script that sourced named configuration

* Sun Nov 15 2009 Stjepan Gros <stjepan.gros@gmail.com> - 0.7-3
- All BuildRequires are now specified in the main package section
- Added parallel make to all the places
- Added "install -p" to all the installations in order to preserve timestamps
- Created some minimal configuration
- Switched services definition to configuration directory
- Fixed ownership of the directory %%{_datadir}/vuurmuur

* Sat Nov 14 2009 Stjepan Gros <stjepan.gros@gmail.com> - 0.7-2
- Skipped release number 1 because of error in the previous
  version of package
- Fixes based on the review on bugzilla
  https://bugzilla.redhat.com/show_bug.cgi?id=528108#c1
  https://bugzilla.redhat.com/show_bug.cgi?id=528108#c2

* Wed Sep  2 2009 Stjepan Gros <stjepan.gros@gmail.com> - 0.7-0
- Initial package

