#!/bin/bash

# This is an implementation of a start-script for Vuurmuur.
#
# (c) 2004-2007 Victor Julien, released under GPL.

# Make RedHat happy:
#
# chkconfig: - 91 9
# Description: Vuurmuur is a firewall.
#

### BEGIN INIT INFO
# Provides: vuurmuur
# Required-Start: $local_fs $network $syslog
# Required-Stop: $local_fs $network $syslog
# Default-Start:
# Default-Stop: 0 1 2 3 4 5 6
# Short-Description: start|stop|status|restart|condrestart|force-reload Vuurmuur firewall
# Description: control Vuurmuur firewall
### END INIT INFO

# Source function library.
. /etc/rc.d/init.d/functions

# where do the executables reside? NOTE: no trailing slash

# space separated list of modules to load on start, or 'none' if none ;-)
MODULES_TO_LOAD="ip_tables iptable_filter iptable_mangle iptable_nat ip_conntrack ipt_state ip_conntrack_ftp ip_nat_ftp ip_queue"
#MODULES_TO_LOAD="none"

PATH=/bin:/usr/bin:/sbin:/usr/sbin

vuurmuur_exec="/usr/bin/vuurmuur"
vuurmuur_prog="vuurmuur"
logger_exec="/usr/bin/vuurmuur_log"
logger_prog="/usr/bin/vuurmuur_log"
lockfile=/var/lock/subsys/vuurmuur
lockfile_log=/var/lock/subsys/vuurmuur_log

[ -e /etc/sysconfig/$vuurmuur_prog ] && . /etc/sysconfig/$vuurmuur_prog
[ -e /etc/sysconfig/$logger_prog ] && . /etc/sysconfig/$logger_prog

rh_status() {
    # run checks to determine if the service is running or use generic status
    status $vuurmuur_prog
}

rh_status_q() {
    rh_status >/dev/null 2>&1
}

case "$1" in
	start)
		# check if vuurmuur is configured
		IFNUM=`/usr/bin/vuurmuur_script --list --interface any | wc -l`
		if [ "$IFNUM" = "0" ]; then
			echo "FAILED: please configure Vuurmuur first by defining at least one interface."
			echo "HINT: Use vuurmuur_conf tool from the vuurmuur-tui package."
			exit 1
		fi

		echo -n "Starting $vuurmuur_prog:"
		daemon $vuurmuur_prog -l
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] || exit $RETVAL
		touch $lockfile

		echo -n "Starting $logger_prog:"
		daemon $logger_prog
		RETVAL=$?
		echo
		if [ $RETVAL -ne 0 ]; then
			killproc $vuurmuur_prog
			exit $RETVAL
		fi
		touch $lockfile_log
		;;

	stop)
		echo -n "Shutting down $vuurmuur_prog: "
		killproc $vuurmuur_prog
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && rm -f $lockfile

		echo -n "Shutting down $logger_prog: "
		killproc $logger_prog
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && rm -f $lockfile_log
                ;;

	condrestart)
		rh_status_q || exit 0
		$0 restart
		;;

	status)
		status $vuurmuur_prog
		status $logger_prog
                ;;

	force-reload|restart)
		$0 stop
		$0 start
		;;
	*)
		echo "Usage: /etc/init.d/vuurmuur {start|stop|status|restart|condrestart|force-reload}"
		exit 1
esac

exit 0
